==> deepin-calculator_6.5.12.tar.xz: BUILD/translations/deepin-calculator_bqi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="bqi" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>xatāyê goďên</translation>
    </message>
</context>
<context>
    <name>IconButton</name>
    <message>
        <source>Clear all memory</source>
        <translation>roftên poy virga</translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation>roftên virgār</translation>
    </message>
</context>
<context>
    <name>InputEdit</name>
    <message>
        <source>Delete</source>
        <translation>pāk kerdên</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>pêsandê poy</translation>
    </message>
    <message>
        <source>Use thousands separator</source>
        <translation>joďā konanda hêzārow nê vê kār bovarin</translation>
    </message>
    <message>
        <source>Use ten-thousands separator</source>
        <translation>joďā konanda da&apos; hêzār nê vê kār bovarin</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>vorgandên</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>zê nu anjom biďin</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>jā goro</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>lefgiri</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>jā vandên</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Calculator</source>
        <translation>mâši hêsāv</translation>
    </message>
    <message>
        <source>Standard</source>
        <translation>estāndārd</translation>
    </message>
    <message>
        <source>Scientific</source>
        <translation>elmi</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>hālat</translation>
    </message>
    <message>
        <source>Calculator is an easy to use desktop calculator, supporting standard, scientific and programmer modes.</source>
        <translation>mâši hêsāv ya mâši hêsāv rimizi vā estêfāďe āsow hêď ke zê hālatā estāndārd,elmi ow barnome nivisi lādêrâri êkonê.</translation>
    </message>
    <message>
        <source>Programmer</source>
        <translation>barnome nivis</translation>
    </message>
</context>
<context>
    <name>MemoryButton</name>
    <message>
        <source>Clear memory item</source>
        <translation>roftên āytem virga</translation>
    </message>
    <message>
        <source>Clear all memory</source>
        <translation>roftên poy virga</translation>
    </message>
    <message>
        <source>Memory recall</source>
        <translation>vir vani virga</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>êzāf kerdên āytem vê virga</translation>
    </message>
    <message>
        <source>Memory add</source>
        <translation>êzāf kerdên virga</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>zê āytem virga kam ko</translation>
    </message>
    <message>
        <source>Memory subtract</source>
        <translation>virga nê kam êkonê</translation>
    </message>
    <message>
        <source>Memory store</source>
        <translation>furušgā virga</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>virga</translation>
    </message>
</context>
<context>
    <name>MemoryItemWidget</name>
    <message>
        <source>Copy</source>
        <translation>lefgiri</translation>
    </message>
    <message>
        <source>Clear memory item</source>
        <translation>roftên āytem virga</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>êzāf kerdên āytem vê virga</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>zê āytem virga kam ko</translation>
    </message>
</context>
<context>
    <name>MemoryWidget</name>
    <message>
        <source>Nothing saved in memory</source>
        <translation>hičî mênê virga zaft nîbu</translation>
    </message>
</context>
<context>
    <name>ProExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>xatāyê goďên</translation>
    </message>
</context>
<context>
    <name>ProListView</name>
    <message>
        <source>Copy</source>
        <translation>lefgiri</translation>
    </message>
</context>
<context>
    <name>ProgramModule</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>jā vê jâyi hêsâvi</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>ālêšte manteqi</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>jā vê jâyi dâyrêyi</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>ler xardên vā jā goro kerdên dâyrêyi</translation>
    </message>
</context>
<context>
    <name>ProgrammerItemWidget</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>jā vê jâyi hêsâvi</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>ālêšte manteqi</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>jā vê jâyi dâyrêyi</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>ler xardên vā jā goro kerdên dâyrêyi</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Calculator</source>
        <translation>mâši hêsāv</translation>
    </message>
</context>
<context>
    <name>SciExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>xatāyê goďên</translation>
    </message>
</context>
<context>
    <name>SciHistoryWidget</name>
    <message>
        <source>History</source>
        <translation>virgār</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>virga</translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression error</source>
        <translation>xatāyê goďên</translation>
    </message>
</context>
<context>
    <name>SimpleListModel</name>
    <message>
        <source>No history</source>
        <translation>bî virgār</translation>
    </message>
</context>
<context>
    <name>SimpleListView</name>
    <message>
        <source>Copy</source>
        <translation>lefgiri</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>pāk kerdên</translation>
    </message>
</context>
</TS>

==> deepin-calculator_6.5.29.tar.xz: BUILD/translations/deepin-calculator_bqi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="bqi">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>xatāyê goďên</translation>
    </message>
</context>
<context>
    <name>IconButton</name>
    <message>
        <source>Clear all memory</source>
        <translation>roftên poy virga</translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation>roftên virgār</translation>
    </message>
</context>
<context>
    <name>InputEdit</name>
    <message>
        <source>Delete</source>
        <translation>pāk kerdên</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>pêsandê poy</translation>
    </message>
    <message>
        <source>Use thousands separator</source>
        <translation>joďā konanda hêzārow nê vê kār bovarin</translation>
    </message>
    <message>
        <source>Use ten-thousands separator</source>
        <translation>joďā konanda da&apos; hêzār nê vê kār bovarin</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>vorgandên</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>zê nu anjom biďin</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>jā goro</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>lefgiri</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>jā vandên</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Calculator</source>
        <translation>mâši hêsāv</translation>
    </message>
    <message>
        <source>Standard</source>
        <translation>estāndārd</translation>
    </message>
    <message>
        <source>Scientific</source>
        <translation>elmi</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>hālat</translation>
    </message>
    <message>
        <source>Calculator is an easy to use desktop calculator, supporting standard, scientific and programmer modes.</source>
        <translation>mâši hêsāv ya mâši hêsāv rimizi vā estêfāďe āsow hêď ke zê hālatā estāndārd,elmi ow barnome nivisi lādêrâri êkonê.</translation>
    </message>
    <message>
        <source>Programmer</source>
        <translation>barnome nivis</translation>
    </message>
</context>
<context>
    <name>MemoryButton</name>
    <message>
        <source>Clear memory item</source>
        <translation>roftên āytem virga</translation>
    </message>
    <message>
        <source>Clear all memory</source>
        <translation>roftên poy virga</translation>
    </message>
    <message>
        <source>Memory recall</source>
        <translation>vir vani virga</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>êzāf kerdên āytem vê virga</translation>
    </message>
    <message>
        <source>Memory add</source>
        <translation>êzāf kerdên virga</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>zê āytem virga kam ko</translation>
    </message>
    <message>
        <source>Memory subtract</source>
        <translation>virga nê kam êkonê</translation>
    </message>
    <message>
        <source>Memory store</source>
        <translation>furušgā virga</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>virga</translation>
    </message>
</context>
<context>
    <name>MemoryItemWidget</name>
    <message>
        <source>Copy</source>
        <translation>lefgiri</translation>
    </message>
    <message>
        <source>Clear memory item</source>
        <translation>roftên āytem virga</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>êzāf kerdên āytem vê virga</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>zê āytem virga kam ko</translation>
    </message>
</context>
<context>
    <name>MemoryWidget</name>
    <message>
        <source>Nothing saved in memory</source>
        <translation>hičî mênê virga zaft nîbu</translation>
    </message>
</context>
<context>
    <name>ProExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>xatāyê goďên</translation>
    </message>
</context>
<context>
    <name>ProListView</name>
    <message>
        <source>Copy</source>
        <translation>lefgiri</translation>
    </message>
</context>
<context>
    <name>ProgramModule</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>jā vê jâyi hêsâvi</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>ālêšte manteqi</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>jā vê jâyi dâyrêyi</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>ler xardên vā jā goro kerdên dâyrêyi</translation>
    </message>
</context>
<context>
    <name>ProgrammerItemWidget</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>jā vê jâyi hêsâvi</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>ālêšte manteqi</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>jā vê jâyi dâyrêyi</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>ler xardên vā jā goro kerdên dâyrêyi</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Calculator</source>
        <translation>mâši hêsāv</translation>
    </message>
    <message>
        <source>Getting theme type settings</source>
        <translation>تیم تیپ سیتینگز گرن</translation>
    </message>
    <message>
        <source>Current theme type:</source>
        <translation>جارن تیم تیپ:</translation>
    </message>
    <message>
        <source>Testing translations with longer sentences</source>
        <translation>تست ترنسلاشنز با انجر سينتنس</translation>
    </message>
    <message>
        <source>This is a calculator application that supports basic arithmetic operations</source>
        <translation>ايس ايس ا Calculation ابليكيشن دات سوپرتس بيسك آرثيمتيك اپيرشن</translation>
    </message>
    <message>
        <source>Scientific mode provides advanced mathematical functions and constants</source>
        <translation>ساينتيفك مود بروفيديس ادفانس ماثيماتيك فانشنز ون كونستانتس</translation>
    </message>
    <message>
        <source>Programmer mode offers binary, octal, decimal and hexadecimal calculations</source>
        <translation>بروگرامر مود اوفيرز بائنري، اوكال، دسيمال ون هكسديسيمالي كالكولشنز</translation>
    </message>
    <message>
        <source>History view shows all previous calculations and their results</source>
        <translation>هستوري فيو شوويس ايل بريفيو كالكولشنز ون هير ارزلتس</translation>
    </message>
    <message>
        <source>Memory functions allow you to store and recall calculation results</source>
        <translation>ميمري فانشنز الوود يو تو ستوور ون ريكال كاليكولشن ارزلتس</translation>
    </message>
</context>
<context>
    <name>SciExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>xatāyê goďên</translation>
    </message>
</context>
<context>
    <name>SciHistoryWidget</name>
    <message>
        <source>History</source>
        <translation type="vanished">virgār</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation type="vanished">virga</translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression error</source>
        <translation>xatāyê goďên</translation>
    </message>
</context>
<context>
    <name>SimpleListModel</name>
    <message>
        <source>No history</source>
        <translation>bî virgār</translation>
    </message>
</context>
<context>
    <name>SimpleListView</name>
    <message>
        <source>Copy</source>
        <translation>lefgiri</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>pāk kerdên</translation>
    </message>
</context>
</TS>
